==> arna-0.0.7.tar.gz: lib/src/helpers.dart <==
import 'package:arna/arna.dart';

bool isDark(context) =>
    MediaQuery.of(context).platformBrightness == Brightness.dark;

Color buttonColor(context) =>
    isDark(context) ? Styles.buttonColorDark : Styles.buttonColorLight;

Color buttonColorPressed(context) => isDark(context)
    ? Styles.buttonColorPressedDark
    : Styles.buttonColorPressedLight;

Color buttonColorHover(context) => isDark(context)
    ? Styles.buttonColorHoverDark
    : Styles.buttonColorHoverLight;

Color textFieldColor(context) =>
    isDark(context) ? Styles.textFieldColorDark : Styles.textFieldColorLight;

Color textFieldColorHover(context) => isDark(context)
    ? Styles.textFieldColorHoverDark
    : Styles.textFieldColorHoverLight;

Color backgroundColor(context) =>
    isDark(context) ? Styles.backgroundColorDark : Styles.backgroundColorLight;

Color reverseBackgroundColor(context) =>
    isDark(context) ? Styles.backgroundColorLight : Styles.backgroundColorDark;

Color backgroundColorDisabled(context) => isDark(context)
    ? Styles.backgroundColorDisabledDark
    : Styles.backgroundColorDisabledLight;

Color reverseBackgroundColorDisabled(context) => isDark(context)
    ? Styles.backgroundColorDisabledLight
    : Styles.backgroundColorDisabledDark;

Color headerColor(context) =>
    isDark(context) ? Styles.headerColorDark : Styles.headerColorLight;

Color sideColor(context) =>
    isDark(context) ? Styles.sideColorDark : Styles.sideColorLight;

Color cardColor(context) =>
    isDark(context) ? Styles.cardColorDark : Styles.cardColorLight;

Color cardColorHover(context) =>
    isDark(context) ? Styles.cardColorHoverDark : Styles.cardColorHoverLight;

Color borderColor(context) =>
    isDark(context) ? Styles.borderColorDark : Styles.borderColorLight;

Color reverseBorderColor(context) =>
    isDark(context) ? Styles.borderColorLight : Styles.borderColorDark;

Color primaryTextColor(context) => isDark(context)
    ? Styles.primaryTextColorDark
    : Styles.primaryTextColorLight;

Color reversePrimaryTextColor(context) => isDark(context)
    ? Styles.primaryTextColorLight
    : Styles.primaryTextColorDark;

Color secondaryTextColor(context) => isDark(context)
    ? Styles.secondaryTextColorDark
    : Styles.secondaryTextColorLight;

Color reverseSecondaryTextColor(context) => isDark(context)
    ? Styles.secondaryTextColorLight
    : Styles.secondaryTextColorDark;

Color iconColor(context) =>
    isDark(context) ? Styles.iconColorDark : Styles.iconColorLight;

Color disabledColor(context) =>
    isDark(context) ? Styles.disabledDark : Styles.disabledLight;

TextStyle headline1(context) => TextStyle(
      fontFamily: 'Inter',
      fontWeight: FontWeight.w300,
      fontSize: 32,
      decoration: TextDecoration.none,
      color: primaryTextColor(context),
      overflow: TextOverflow.ellipsis,
    );

TextStyle headline2(context) => TextStyle(
      fontFamily: 'Inter',
      fontWeight: FontWeight.normal,
      fontSize: 23,
      decoration: TextDecoration.none,
      color: primaryTextColor(context),
      overflow: TextOverflow.ellipsis,
    );

TextStyle bodyText(context, {bool disabled = false}) => TextStyle(
      fontFamily: 'Inter',
      fontWeight: FontWeight.normal,
      fontSize: 16,
      decoration: TextDecoration.none,
      color: disabled ? disabledColor(context) : primaryTextColor(context),
      overflow: TextOverflow.ellipsis,
    );

TextStyle buttonText(context, {bool disabled = false}) => TextStyle(
      fontFamily: 'Inter',
      fontWeight: FontWeight.w500,
      fontSize: 16,
      decoration: TextDecoration.none,
      color: disabled ? disabledColor(context) : primaryTextColor(context),
      overflow: TextOverflow.ellipsis,
    );

TextStyle subtitleText(context, {bool disabled = false}) => TextStyle(
      fontFamily: 'Inter',
      fontWeight: FontWeight.normal,
      fontSize: 14,
      decoration: TextDecoration.none,
      color: disabled ? disabledColor(context) : secondaryTextColor(context),
      overflow: TextOverflow.ellipsis,
    );

TextStyle captionText(context) => TextStyle(
      fontFamily: 'Inter',
      fontWeight: FontWeight.w700,
      fontSize: 11,
      decoration: TextDecoration.none,
      color: primaryTextColor(context),
      overflow: TextOverflow.ellipsis,
    );

TextStyle statusBarText(context) => TextStyle(
      fontFamily: 'Inter',
      fontWeight: FontWeight.w700,
      fontSize: 11,
      decoration: TextDecoration.none,
      color: reversePrimaryTextColor(context),
      overflow: TextOverflow.ellipsis,
    );

TextStyle badgeText(context, Color textColor) => TextStyle(
      fontFamily: 'Inter',
      fontWeight: FontWeight.w700,
      fontSize: 11,
      decoration: TextDecoration.none,
      color: textColor,
      overflow: TextOverflow.ellipsis,
    );

double deviceHeight(context) => MediaQuery.of(context).size.height;

double deviceWidth(context) => MediaQuery.of(context).size.width;

bool phone(context) => deviceWidth(context) < 644;

bool tablet(context) => !phone(context) && !desktop(context);

bool desktop(context) => deviceWidth(context) > 960;

BorderRadius borderRadiusAll(double borderRadius) => BorderRadius.all(
      Radius.circular(borderRadius),
    );

==> arna-0.1.2.tar.gz: lib/src/helpers.dart <==
import 'package:arna/arna.dart';

bool isDark(context) =>
    MediaQuery.of(context).platformBrightness == Brightness.dark;

Color buttonColor(context) =>
    isDark(context) ? Styles.buttonColorDark : Styles.buttonColorLight;

Color buttonColorPressed(context) => isDark(context)
    ? Styles.buttonColorPressedDark
    : Styles.buttonColorPressedLight;

Color buttonColorHover(context) => isDark(context)
    ? Styles.buttonColorHoverDark
    : Styles.buttonColorHoverLight;

Color textFieldColor(context) =>
    isDark(context) ? Styles.textFieldColorDark : Styles.textFieldColorLight;

Color textFieldColorHover(context) => isDark(context)
    ? Styles.textFieldColorHoverDark
    : Styles.textFieldColorHoverLight;

Color backgroundColor(context) => ArnaTheme.of(context).scaffoldBackgroundColor;

Color backgroundColorDisabled(context) => isDark(context)
    ? Styles.backgroundColorDisabledDark
    : Styles.backgroundColorDisabledLight;

Color reverseBackgroundColorDisabled(context) => isDark(context)
    ? Styles.backgroundColorDisabledLight
    : Styles.backgroundColorDisabledDark;

Color headerColor(context) => ArnaTheme.of(context).barBackgroundColor;

Color cardColor(context) =>
    ArnaDynamicColor.resolve(ArnaColors.cardColor, context);

Color cardColorHover(context) =>
    isDark(context) ? Styles.cardColorHoverDark : Styles.cardColorHoverLight;

Color primaryTextColor(context) => isDark(context)
    ? Styles.primaryTextColorDark
    : Styles.primaryTextColorLight;

Color reversePrimaryTextColor(context) => isDark(context)
    ? Styles.primaryTextColorLight
    : Styles.primaryTextColorDark;

Color secondaryTextColor(context) => isDark(context)
    ? Styles.secondaryTextColorDark
    : Styles.secondaryTextColorLight;

Color reverseSecondaryTextColor(context) => isDark(context)
    ? Styles.secondaryTextColorLight
    : Styles.secondaryTextColorDark;

TextStyle subtitleText(context, {bool disabled = false}) => TextStyle(
      fontFamily: 'Inter',
      fontWeight: FontWeight.normal,
      fontSize: 14,
      decoration: TextDecoration.none,
      color: ArnaDynamicColor.resolve(
        disabled ? ArnaColors.disabledColor : ArnaColors.secondaryTextColor,
        context,
      ),
      overflow: TextOverflow.ellipsis,
    );

double deviceHeight(context) => MediaQuery.of(context).size.height;

double deviceWidth(context) => MediaQuery.of(context).size.width;

bool phone(context) => deviceWidth(context) < 644;

bool tablet(context) => !phone(context) && !desktop(context);

bool desktop(context) => deviceWidth(context) > 960;

BorderRadius borderRadiusAll(double borderRadius) => BorderRadius.all(
      Radius.circular(borderRadius),
    );
